@@ -1,7 +1,9 @@
-from __future__ import absolute_import
-
+from typing import TYPE_CHECKING
 from unittest import TestCase as BaseTestCase, TestSuite
 
+if TYPE_CHECKING:
+    from ..sybil import Sybil
+
 
 class TestCase(BaseTestCase):
 
@@ -16,7 +18,7 @@ class TestCase(BaseTestCase):
 
     def id(self):
         return '{},line:{},column:{}'.format(
-            self.example.document.path, self.example.line, self.example.column
+            self.example.path, self.example.line, self.example.column
         )
 
     __str__ = __repr__ = id
@@ -32,18 +34,21 @@ class TestCase(BaseTestCase):
             cls.sybil.teardown(cls.namespace)
 
 
-def unittest_integration(sybil):
+def unittest_integration(*sybils: 'Sybil'):
 
     def load_tests(loader=None, tests=None, pattern=None):
         suite = TestSuite()
-        for document in sybil.all_documents():
+        for sybil in sybils:
+            for path in sorted(sybil.path.glob('**/*')):
+                if path.is_file() and sybil.should_parse(path):
+                    document = sybil.parse(path)
 
-            case = type(document.path, (TestCase, ), dict(
-                sybil=sybil, namespace=document.namespace,
-            ))
+                    case = type(document.path, (TestCase, ), dict(
+                        sybil=sybil, namespace=document.namespace,
+                    ))
 
-            for example in document:
-                suite.addTest(case(example))
+                    for example in document:
+                        suite.addTest(case(example))
 
         return suite
 
